@@ -740,10 +740,10 @@ enum ZigClangBuiltinTypeKind {
     ZigClangBuiltinTypeOCLIntelSubgroupAVCImeResult,
     ZigClangBuiltinTypeOCLIntelSubgroupAVCRefResult,
     ZigClangBuiltinTypeOCLIntelSubgroupAVCSicResult,
-    ZigClangBuiltinTypeOCLIntelSubgroupAVCImeResultSingleRefStreamout,
-    ZigClangBuiltinTypeOCLIntelSubgroupAVCImeResultDualRefStreamout,
-    ZigClangBuiltinTypeOCLIntelSubgroupAVCImeSingleRefStreamin,
-    ZigClangBuiltinTypeOCLIntelSubgroupAVCImeDualRefStreamin,
+    ZigClangBuiltinTypeOCLIntelSubgroupAVCImeResultSingleReferenceStreamout,
+    ZigClangBuiltinTypeOCLIntelSubgroupAVCImeResultDualReferenceStreamout,
+    ZigClangBuiltinTypeOCLIntelSubgroupAVCImeSingleReferenceStreamin,
+    ZigClangBuiltinTypeOCLIntelSubgroupAVCImeDualReferenceStreamin,
     ZigClangBuiltinTypeSveInt8,
     ZigClangBuiltinTypeSveInt16,
     ZigClangBuiltinTypeSveInt32,
@@ -793,6 +793,9 @@ enum ZigClangBuiltinTypeKind {
     ZigClangBuiltinTypeSveFloat64x4,
     ZigClangBuiltinTypeSveBFloat16x4,
     ZigClangBuiltinTypeSveBool,
+    ZigClangBuiltinTypeSveBoolx2,
+    ZigClangBuiltinTypeSveBoolx4,
+    ZigClangBuiltinTypeSveCount,
     ZigClangBuiltinTypeVectorQuad,
     ZigClangBuiltinTypeVectorPair,
     ZigClangBuiltinTypeRvvInt8mf8,
@@ -861,6 +864,233 @@ enum ZigClangBuiltinTypeKind {
     ZigClangBuiltinTypeRvvBool16,
     ZigClangBuiltinTypeRvvBool32,
     ZigClangBuiltinTypeRvvBool64,
+    ZigClangBuiltinTypeRvvInt8mf8x2,
+    ZigClangBuiltinTypeRvvInt8mf8x3,
+    ZigClangBuiltinTypeRvvInt8mf8x4,
+    ZigClangBuiltinTypeRvvInt8mf8x5,
+    ZigClangBuiltinTypeRvvInt8mf8x6,
+    ZigClangBuiltinTypeRvvInt8mf8x7,
+    ZigClangBuiltinTypeRvvInt8mf8x8,
+    ZigClangBuiltinTypeRvvInt8mf4x2,
+    ZigClangBuiltinTypeRvvInt8mf4x3,
+    ZigClangBuiltinTypeRvvInt8mf4x4,
+    ZigClangBuiltinTypeRvvInt8mf4x5,
+    ZigClangBuiltinTypeRvvInt8mf4x6,
+    ZigClangBuiltinTypeRvvInt8mf4x7,
+    ZigClangBuiltinTypeRvvInt8mf4x8,
+    ZigClangBuiltinTypeRvvInt8mf2x2,
+    ZigClangBuiltinTypeRvvInt8mf2x3,
+    ZigClangBuiltinTypeRvvInt8mf2x4,
+    ZigClangBuiltinTypeRvvInt8mf2x5,
+    ZigClangBuiltinTypeRvvInt8mf2x6,
+    ZigClangBuiltinTypeRvvInt8mf2x7,
+    ZigClangBuiltinTypeRvvInt8mf2x8,
+    ZigClangBuiltinTypeRvvInt8m1x2,
+    ZigClangBuiltinTypeRvvInt8m1x3,
+    ZigClangBuiltinTypeRvvInt8m1x4,
+    ZigClangBuiltinTypeRvvInt8m1x5,
+    ZigClangBuiltinTypeRvvInt8m1x6,
+    ZigClangBuiltinTypeRvvInt8m1x7,
+    ZigClangBuiltinTypeRvvInt8m1x8,
+    ZigClangBuiltinTypeRvvInt8m2x2,
+    ZigClangBuiltinTypeRvvInt8m2x3,
+    ZigClangBuiltinTypeRvvInt8m2x4,
+    ZigClangBuiltinTypeRvvInt8m4x2,
+    ZigClangBuiltinTypeRvvUint8mf8x2,
+    ZigClangBuiltinTypeRvvUint8mf8x3,
+    ZigClangBuiltinTypeRvvUint8mf8x4,
+    ZigClangBuiltinTypeRvvUint8mf8x5,
+    ZigClangBuiltinTypeRvvUint8mf8x6,
+    ZigClangBuiltinTypeRvvUint8mf8x7,
+    ZigClangBuiltinTypeRvvUint8mf8x8,
+    ZigClangBuiltinTypeRvvUint8mf4x2,
+    ZigClangBuiltinTypeRvvUint8mf4x3,
+    ZigClangBuiltinTypeRvvUint8mf4x4,
+    ZigClangBuiltinTypeRvvUint8mf4x5,
+    ZigClangBuiltinTypeRvvUint8mf4x6,
+    ZigClangBuiltinTypeRvvUint8mf4x7,
+    ZigClangBuiltinTypeRvvUint8mf4x8,
+    ZigClangBuiltinTypeRvvUint8mf2x2,
+    ZigClangBuiltinTypeRvvUint8mf2x3,
+    ZigClangBuiltinTypeRvvUint8mf2x4,
+    ZigClangBuiltinTypeRvvUint8mf2x5,
+    ZigClangBuiltinTypeRvvUint8mf2x6,
+    ZigClangBuiltinTypeRvvUint8mf2x7,
+    ZigClangBuiltinTypeRvvUint8mf2x8,
+    ZigClangBuiltinTypeRvvUint8m1x2,
+    ZigClangBuiltinTypeRvvUint8m1x3,
+    ZigClangBuiltinTypeRvvUint8m1x4,
+    ZigClangBuiltinTypeRvvUint8m1x5,
+    ZigClangBuiltinTypeRvvUint8m1x6,
+    ZigClangBuiltinTypeRvvUint8m1x7,
+    ZigClangBuiltinTypeRvvUint8m1x8,
+    ZigClangBuiltinTypeRvvUint8m2x2,
+    ZigClangBuiltinTypeRvvUint8m2x3,
+    ZigClangBuiltinTypeRvvUint8m2x4,
+    ZigClangBuiltinTypeRvvUint8m4x2,
+    ZigClangBuiltinTypeRvvInt16mf4x2,
+    ZigClangBuiltinTypeRvvInt16mf4x3,
+    ZigClangBuiltinTypeRvvInt16mf4x4,
+    ZigClangBuiltinTypeRvvInt16mf4x5,
+    ZigClangBuiltinTypeRvvInt16mf4x6,
+    ZigClangBuiltinTypeRvvInt16mf4x7,
+    ZigClangBuiltinTypeRvvInt16mf4x8,
+    ZigClangBuiltinTypeRvvInt16mf2x2,
+    ZigClangBuiltinTypeRvvInt16mf2x3,
+    ZigClangBuiltinTypeRvvInt16mf2x4,
+    ZigClangBuiltinTypeRvvInt16mf2x5,
+    ZigClangBuiltinTypeRvvInt16mf2x6,
+    ZigClangBuiltinTypeRvvInt16mf2x7,
+    ZigClangBuiltinTypeRvvInt16mf2x8,
+    ZigClangBuiltinTypeRvvInt16m1x2,
+    ZigClangBuiltinTypeRvvInt16m1x3,
+    ZigClangBuiltinTypeRvvInt16m1x4,
+    ZigClangBuiltinTypeRvvInt16m1x5,
+    ZigClangBuiltinTypeRvvInt16m1x6,
+    ZigClangBuiltinTypeRvvInt16m1x7,
+    ZigClangBuiltinTypeRvvInt16m1x8,
+    ZigClangBuiltinTypeRvvInt16m2x2,
+    ZigClangBuiltinTypeRvvInt16m2x3,
+    ZigClangBuiltinTypeRvvInt16m2x4,
+    ZigClangBuiltinTypeRvvInt16m4x2,
+    ZigClangBuiltinTypeRvvUint16mf4x2,
+    ZigClangBuiltinTypeRvvUint16mf4x3,
+    ZigClangBuiltinTypeRvvUint16mf4x4,
+    ZigClangBuiltinTypeRvvUint16mf4x5,
+    ZigClangBuiltinTypeRvvUint16mf4x6,
+    ZigClangBuiltinTypeRvvUint16mf4x7,
+    ZigClangBuiltinTypeRvvUint16mf4x8,
+    ZigClangBuiltinTypeRvvUint16mf2x2,
+    ZigClangBuiltinTypeRvvUint16mf2x3,
+    ZigClangBuiltinTypeRvvUint16mf2x4,
+    ZigClangBuiltinTypeRvvUint16mf2x5,
+    ZigClangBuiltinTypeRvvUint16mf2x6,
+    ZigClangBuiltinTypeRvvUint16mf2x7,
+    ZigClangBuiltinTypeRvvUint16mf2x8,
+    ZigClangBuiltinTypeRvvUint16m1x2,
+    ZigClangBuiltinTypeRvvUint16m1x3,
+    ZigClangBuiltinTypeRvvUint16m1x4,
+    ZigClangBuiltinTypeRvvUint16m1x5,
+    ZigClangBuiltinTypeRvvUint16m1x6,
+    ZigClangBuiltinTypeRvvUint16m1x7,
+    ZigClangBuiltinTypeRvvUint16m1x8,
+    ZigClangBuiltinTypeRvvUint16m2x2,
+    ZigClangBuiltinTypeRvvUint16m2x3,
+    ZigClangBuiltinTypeRvvUint16m2x4,
+    ZigClangBuiltinTypeRvvUint16m4x2,
+    ZigClangBuiltinTypeRvvInt32mf2x2,
+    ZigClangBuiltinTypeRvvInt32mf2x3,
+    ZigClangBuiltinTypeRvvInt32mf2x4,
+    ZigClangBuiltinTypeRvvInt32mf2x5,
+    ZigClangBuiltinTypeRvvInt32mf2x6,
+    ZigClangBuiltinTypeRvvInt32mf2x7,
+    ZigClangBuiltinTypeRvvInt32mf2x8,
+    ZigClangBuiltinTypeRvvInt32m1x2,
+    ZigClangBuiltinTypeRvvInt32m1x3,
+    ZigClangBuiltinTypeRvvInt32m1x4,
+    ZigClangBuiltinTypeRvvInt32m1x5,
+    ZigClangBuiltinTypeRvvInt32m1x6,
+    ZigClangBuiltinTypeRvvInt32m1x7,
+    ZigClangBuiltinTypeRvvInt32m1x8,
+    ZigClangBuiltinTypeRvvInt32m2x2,
+    ZigClangBuiltinTypeRvvInt32m2x3,
+    ZigClangBuiltinTypeRvvInt32m2x4,
+    ZigClangBuiltinTypeRvvInt32m4x2,
+    ZigClangBuiltinTypeRvvUint32mf2x2,
+    ZigClangBuiltinTypeRvvUint32mf2x3,
+    ZigClangBuiltinTypeRvvUint32mf2x4,
+    ZigClangBuiltinTypeRvvUint32mf2x5,
+    ZigClangBuiltinTypeRvvUint32mf2x6,
+    ZigClangBuiltinTypeRvvUint32mf2x7,
+    ZigClangBuiltinTypeRvvUint32mf2x8,
+    ZigClangBuiltinTypeRvvUint32m1x2,
+    ZigClangBuiltinTypeRvvUint32m1x3,
+    ZigClangBuiltinTypeRvvUint32m1x4,
+    ZigClangBuiltinTypeRvvUint32m1x5,
+    ZigClangBuiltinTypeRvvUint32m1x6,
+    ZigClangBuiltinTypeRvvUint32m1x7,
+    ZigClangBuiltinTypeRvvUint32m1x8,
+    ZigClangBuiltinTypeRvvUint32m2x2,
+    ZigClangBuiltinTypeRvvUint32m2x3,
+    ZigClangBuiltinTypeRvvUint32m2x4,
+    ZigClangBuiltinTypeRvvUint32m4x2,
+    ZigClangBuiltinTypeRvvInt64m1x2,
+    ZigClangBuiltinTypeRvvInt64m1x3,
+    ZigClangBuiltinTypeRvvInt64m1x4,
+    ZigClangBuiltinTypeRvvInt64m1x5,
+    ZigClangBuiltinTypeRvvInt64m1x6,
+    ZigClangBuiltinTypeRvvInt64m1x7,
+    ZigClangBuiltinTypeRvvInt64m1x8,
+    ZigClangBuiltinTypeRvvInt64m2x2,
+    ZigClangBuiltinTypeRvvInt64m2x3,
+    ZigClangBuiltinTypeRvvInt64m2x4,
+    ZigClangBuiltinTypeRvvInt64m4x2,
+    ZigClangBuiltinTypeRvvUint64m1x2,
+    ZigClangBuiltinTypeRvvUint64m1x3,
+    ZigClangBuiltinTypeRvvUint64m1x4,
+    ZigClangBuiltinTypeRvvUint64m1x5,
+    ZigClangBuiltinTypeRvvUint64m1x6,
+    ZigClangBuiltinTypeRvvUint64m1x7,
+    ZigClangBuiltinTypeRvvUint64m1x8,
+    ZigClangBuiltinTypeRvvUint64m2x2,
+    ZigClangBuiltinTypeRvvUint64m2x3,
+    ZigClangBuiltinTypeRvvUint64m2x4,
+    ZigClangBuiltinTypeRvvUint64m4x2,
+    ZigClangBuiltinTypeRvvFloat16mf4x2,
+    ZigClangBuiltinTypeRvvFloat16mf4x3,
+    ZigClangBuiltinTypeRvvFloat16mf4x4,
+    ZigClangBuiltinTypeRvvFloat16mf4x5,
+    ZigClangBuiltinTypeRvvFloat16mf4x6,
+    ZigClangBuiltinTypeRvvFloat16mf4x7,
+    ZigClangBuiltinTypeRvvFloat16mf4x8,
+    ZigClangBuiltinTypeRvvFloat16mf2x2,
+    ZigClangBuiltinTypeRvvFloat16mf2x3,
+    ZigClangBuiltinTypeRvvFloat16mf2x4,
+    ZigClangBuiltinTypeRvvFloat16mf2x5,
+    ZigClangBuiltinTypeRvvFloat16mf2x6,
+    ZigClangBuiltinTypeRvvFloat16mf2x7,
+    ZigClangBuiltinTypeRvvFloat16mf2x8,
+    ZigClangBuiltinTypeRvvFloat16m1x2,
+    ZigClangBuiltinTypeRvvFloat16m1x3,
+    ZigClangBuiltinTypeRvvFloat16m1x4,
+    ZigClangBuiltinTypeRvvFloat16m1x5,
+    ZigClangBuiltinTypeRvvFloat16m1x6,
+    ZigClangBuiltinTypeRvvFloat16m1x7,
+    ZigClangBuiltinTypeRvvFloat16m1x8,
+    ZigClangBuiltinTypeRvvFloat16m2x2,
+    ZigClangBuiltinTypeRvvFloat16m2x3,
+    ZigClangBuiltinTypeRvvFloat16m2x4,
+    ZigClangBuiltinTypeRvvFloat16m4x2,
+    ZigClangBuiltinTypeRvvFloat32mf2x2,
+    ZigClangBuiltinTypeRvvFloat32mf2x3,
+    ZigClangBuiltinTypeRvvFloat32mf2x4,
+    ZigClangBuiltinTypeRvvFloat32mf2x5,
+    ZigClangBuiltinTypeRvvFloat32mf2x6,
+    ZigClangBuiltinTypeRvvFloat32mf2x7,
+    ZigClangBuiltinTypeRvvFloat32mf2x8,
+    ZigClangBuiltinTypeRvvFloat32m1x2,
+    ZigClangBuiltinTypeRvvFloat32m1x3,
+    ZigClangBuiltinTypeRvvFloat32m1x4,
+    ZigClangBuiltinTypeRvvFloat32m1x5,
+    ZigClangBuiltinTypeRvvFloat32m1x6,
+    ZigClangBuiltinTypeRvvFloat32m1x7,
+    ZigClangBuiltinTypeRvvFloat32m1x8,
+    ZigClangBuiltinTypeRvvFloat32m2x2,
+    ZigClangBuiltinTypeRvvFloat32m2x3,
+    ZigClangBuiltinTypeRvvFloat32m2x4,
+    ZigClangBuiltinTypeRvvFloat32m4x2,
+    ZigClangBuiltinTypeRvvFloat64m1x2,
+    ZigClangBuiltinTypeRvvFloat64m1x3,
+    ZigClangBuiltinTypeRvvFloat64m1x4,
+    ZigClangBuiltinTypeRvvFloat64m1x5,
+    ZigClangBuiltinTypeRvvFloat64m1x6,
+    ZigClangBuiltinTypeRvvFloat64m1x7,
+    ZigClangBuiltinTypeRvvFloat64m1x8,
+    ZigClangBuiltinTypeRvvFloat64m2x2,
+    ZigClangBuiltinTypeRvvFloat64m2x3,
+    ZigClangBuiltinTypeRvvFloat64m2x4,
+    ZigClangBuiltinTypeRvvFloat64m4x2,
+    ZigClangBuiltinTypeWasmExternRef,
     ZigClangBuiltinTypeVoid,
     ZigClangBuiltinTypeBool,
     ZigClangBuiltinTypeChar_U,
@@ -989,9 +1219,16 @@ enum ZigClangAPFloatBase_Semantics {
     ZigClangAPFloatBase_Semantics_BFloat,
     ZigClangAPFloatBase_Semantics_IEEEsingle,
     ZigClangAPFloatBase_Semantics_IEEEdouble,
-    ZigClangAPFloatBase_Semantics_x87DoubleExtended,
     ZigClangAPFloatBase_Semantics_IEEEquad,
     ZigClangAPFloatBase_Semantics_PPCDoubleDouble,
+    ZigClangAPFloatBase_Semantics_Float8E5M2,
+    ZigClangAPFloatBase_Semantics_Float8E5M2FNUZ,
+    ZigClangAPFloatBase_Semantics_Float8E4M3FN,
+    ZigClangAPFloatBase_Semantics_Float8E4M3FNUZ,
+    ZigClangAPFloatBase_Semantics_Float8E4M3B11FNUZ,
+    ZigClangAPFloatBase_Semantics_FloatTF32,
+    ZigClangAPFloatBase_Semantics_x87DoubleExtended,
+    ZigClangAPFloatBase_Semantics_MaxSemantics = ZigClangAPFloatBase_Semantics_x87DoubleExtended,
 };
 
 enum ZigClangStringLiteral_StringKind {
@@ -1273,6 +1510,7 @@ ZIG_EXTERN_C struct ZigClangSourceLocation ZigClangDeclStmt_getBeginLoc(const st
 ZIG_EXTERN_C unsigned ZigClangAPFloat_convertToHexString(const struct ZigClangAPFloat *self, char *DST,
         unsigned HexDigits, bool UpperCase, enum ZigClangAPFloat_roundingMode RM);
 ZIG_EXTERN_C double ZigClangFloatingLiteral_getValueAsApproximateDouble(const ZigClangFloatingLiteral *self);
+ZIG_EXTERN_C void ZigClangFloatingLiteral_getValueAsApproximateQuadBits(const ZigClangFloatingLiteral *self, uint64_t *low, uint64_t *high);
 ZIG_EXTERN_C struct ZigClangSourceLocation ZigClangFloatingLiteral_getBeginLoc(const struct ZigClangFloatingLiteral *);
 ZIG_EXTERN_C ZigClangAPFloatBase_Semantics ZigClangFloatingLiteral_getRawSemantics(const ZigClangFloatingLiteral *self);
 
